==> igniteui-react-16.16.2.tgz: package/esm2015/lib/igr-dock-manager-resource-strings.js <==
import * as React from 'react';
import { DockManagerResourceStrings } from "./DockManagerResourceStrings";
import { TypeRegistrar } from "igniteui-react-core";
import { NamePatcher, getModifiedProps, isValidProp, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
/**
 * Describes dock manager resource strings.
*/
export class IgrDockManagerResourceStrings extends React.Component {
    constructor(props) {
        super(props);
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new DockManagerResourceStrings();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    componentDidMount() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        return null;
    }
    get close() {
        return this.i.e;
    }
    set close(v) {
        this.i.e = v;
    }
    get pin() {
        return this.i.l;
    }
    set pin(v) {
        this.i.l = v;
    }
    get unpin() {
        return this.i.m;
    }
    set unpin(v) {
        this.i.m = v;
    }
    get maximize() {
        return this.i.g;
    }
    set maximize(v) {
        this.i.g = v;
    }
    get minimize() {
        return this.i.h;
    }
    set minimize(v) {
        this.i.h = v;
    }
    get moreOptions() {
        return this.i.i;
    }
    set moreOptions(v) {
        this.i.i = v;
    }
    get moreTabs() {
        return this.i.j;
    }
    set moreTabs(v) {
        this.i.j = v;
    }
    get panes() {
        return this.i.k;
    }
    set panes(v) {
        this.i.k = v;
    }
    get documents() {
        return this.i.f;
    }
    set documents(v) {
        this.i.f = v;
    }
    findByName(name) {
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("DockManagerResourceStrings");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
}

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/igr-dock-manager-resource-strings.js <==
import { DockManagerResourceStrings as DockManagerResourceStrings_internal } from "./DockManagerResourceStrings";
/**
 * Describes dock manager resource strings.
*/
export class IgrDockManagerResourceStrings {
    createImplementation() {
        return new DockManagerResourceStrings_internal();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    get close() {
        return this.i.e;
    }
    set close(v) {
        this.i.e = v;
    }
    get pin() {
        return this.i.l;
    }
    set pin(v) {
        this.i.l = v;
    }
    get unpin() {
        return this.i.m;
    }
    set unpin(v) {
        this.i.m = v;
    }
    get maximize() {
        return this.i.g;
    }
    set maximize(v) {
        this.i.g = v;
    }
    get minimize() {
        return this.i.h;
    }
    set minimize(v) {
        this.i.h = v;
    }
    get moreOptions() {
        return this.i.i;
    }
    set moreOptions(v) {
        this.i.i = v;
    }
    get moreTabs() {
        return this.i.j;
    }
    set moreTabs(v) {
        this.i.j = v;
    }
    get panes() {
        return this.i.k;
    }
    set panes(v) {
        this.i.k = v;
    }
    get documents() {
        return this.i.f;
    }
    set documents(v) {
        this.i.f = v;
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
}
